# {py:mod}`ngff_zarr.from_ngff_zarr`

```{py:module} ngff_zarr.from_ngff_zarr
```

```{autodoc2-docstring} ngff_zarr.from_ngff_zarr
:allowtitles:
```

## Module Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`from_ngff_zarr <ngff_zarr.from_ngff_zarr.from_ngff_zarr>`
  - ```{autodoc2-docstring} ngff_zarr.from_ngff_zarr.from_ngff_zarr
    :summary:
    ```
````

### API

````{py:function} from_ngff_zarr(store: typing.Union[collections.abc.MutableMapping, str, pathlib.Path, zarr.storage.BaseStore]) -> ngff_zarr.to_multiscales.Multiscales
:canonical: ngff_zarr.from_ngff_zarr.from_ngff_zarr

```{autodoc2-docstring} ngff_zarr.from_ngff_zarr.from_ngff_zarr
```
````
